==> apache-openmeetings-7.1.0-src.tar.gz: openmeetings-db/src/main/java/org/apache/openmeetings/db/entity/HistoricalEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.db.entity;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.MappedSuperclass;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.apache.openmeetings.db.bind.adapter.BooleanAdapter;
import org.apache.openmeetings.db.bind.adapter.DateAdapter;

@MappedSuperclass
@XmlAccessorType(XmlAccessType.FIELD)
public abstract class HistoricalEntity implements IDataProviderEntity {
	private static final long serialVersionUID = 1L;

	@Column(name = "inserted")
	@XmlElement(name = "created", required = false)
	@XmlJavaTypeAdapter(DateAdapter.class)
	private Date inserted;

	@Column(name = "updated")
	@XmlElement(name = "updated", required = false)
	@XmlJavaTypeAdapter(DateAdapter.class)
	private Date updated;

	@Column(name = "deleted", nullable = false)
	@XmlElement(name = "deleted", required = false)
	@XmlJavaTypeAdapter(value = BooleanAdapter.class, type = boolean.class)
	private boolean deleted;

	public Date getInserted() {
		return inserted;
	}

	public void setInserted(Date inserted) {
		this.inserted = inserted;
	}

	public Date getUpdated() {
		return updated;
	}

	public void setUpdated(Date updated) {
		this.updated = updated;
	}

	public boolean isDeleted() {
		return deleted;
	}

	public void setDeleted(boolean deleted) {
		this.deleted = deleted;
	}

	@PrePersist
	void insertedAt() {
		this.inserted = new Date();
	}

	@PreUpdate
	void updatedAt() {
		this.updated = new Date();
	}
}

==> apache-openmeetings-8.1.0-src.tar.gz: openmeetings-db/src/main/java/org/apache/openmeetings/db/entity/HistoricalEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License") +  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openmeetings.db.entity;

import java.util.Date;

import jakarta.persistence.Column;
import jakarta.persistence.MappedSuperclass;
import jakarta.persistence.PrePersist;
import jakarta.persistence.PreUpdate;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.apache.openmeetings.db.bind.adapter.BooleanAdapter;
import org.apache.openmeetings.db.bind.adapter.DateAdapter;

@MappedSuperclass
@XmlAccessorType(XmlAccessType.FIELD)
public abstract class HistoricalEntity implements IDataProviderEntity {
	private static final long serialVersionUID = 1L;

	@Column(name = "inserted")
	@XmlElement(name = "created", required = false)
	@XmlJavaTypeAdapter(DateAdapter.class)
	private Date inserted;

	@Column(name = "updated")
	@XmlElement(name = "updated", required = false)
	@XmlJavaTypeAdapter(DateAdapter.class)
	private Date updated;

	@Column(name = "deleted", nullable = false)
	@XmlElement(name = "deleted", required = false)
	@XmlJavaTypeAdapter(value = BooleanAdapter.class, type = boolean.class)
	private boolean deleted;

	public Date getInserted() {
		return inserted;
	}

	public void setInserted(Date inserted) {
		this.inserted = inserted;
	}

	public Date getUpdated() {
		return updated;
	}

	public void setUpdated(Date updated) {
		this.updated = updated;
	}

	public boolean isDeleted() {
		return deleted;
	}

	public void setDeleted(boolean deleted) {
		this.deleted = deleted;
	}

	@PrePersist
	void insertedAt() {
		this.inserted = new Date();
	}

	@PreUpdate
	void updatedAt() {
		this.updated = new Date();
	}
}
